@@ -40,6 +40,7 @@
 
 #include "PhylogeneticsApplicationTools.h"
 #include "../Model/SubstitutionModel.h"
+#include "../Model/WrappedModel.h"
 #include "../Model/Protein/Coala.h"
 #include "../Model/FrequenciesSet/MvaFrequenciesSet.h"
 #include "../Likelihood/TreeLikelihood.h"
@@ -101,7 +102,7 @@ Tree* PhylogeneticsApplicationTools::getTree(
   const string& suffix,
   bool suffixIsOptional,
   bool verbose,
-  int warn) throw (Exception)
+  int warn)
 {
   string format = ApplicationTools::getStringParameter(prefix + "tree.format", params, "Newick", suffix, suffixIsOptional, warn);
   string treeFilePath = ApplicationTools::getAFilePath(prefix + "tree.file", params, true, true, suffix, suffixIsOptional, "none", warn);
@@ -125,7 +126,7 @@ vector<Tree*> PhylogeneticsApplicationTools::getTrees(
   const string& suffix,
   bool suffixIsOptional,
   bool verbose,
-  int warn) throw (Exception)
+  int warn)
 {
   string format = ApplicationTools::getStringParameter(prefix + "trees.format", params, "Newick", suffix, suffixIsOptional, warn);
   string treeFilePath = ApplicationTools::getAFilePath(prefix + "trees.file", params, true, true, suffix, suffixIsOptional, "none", warn);
@@ -162,7 +163,7 @@ SubstitutionModel* PhylogeneticsApplicationTools::getSubstitutionModel(
   const string& suffix,
   bool suffixIsOptional,
   bool verbose,
-  int warn) throw (Exception)
+  int warn)
 {
   BppOSubstitutionModelFormat bIO(BppOSubstitutionModelFormat::ALL, true, true, true, verbose, warn + 1);
   string modelDescription;
@@ -191,7 +192,7 @@ TransitionModel* PhylogeneticsApplicationTools::getTransitionModel(
   const string& suffix,
   bool suffixIsOptional,
   bool verbose,
-  int warn) throw (Exception)
+  int warn)
 {
   BppOTransitionModelFormat bIO(BppOSubstitutionModelFormat::ALL, true, true, true, verbose, warn + 1);
   string modelDescription;
@@ -220,7 +221,7 @@ void PhylogeneticsApplicationTools::setSubstitutionModelParametersInitialValuesW
   size_t modelNumber,
   const SiteContainer* data,
   std::map<std::string, std::string>& sharedParams,
-  bool verbose) throw (Exception)
+  bool verbose)
 {
   string initFreqs = ApplicationTools::getStringParameter(model.getNamespace() + "initFreqs", unparsedParameterValues, "", "", true, 2);
 
@@ -257,7 +258,7 @@ void PhylogeneticsApplicationTools::setSubstitutionModelParametersInitialValuesW
   for (size_t i = 0; i < pl.size(); ++i)
   {
     AutoParameter ap(pl[i]);
-    ap.setMessageHandler(ApplicationTools::warning);
+    ap.setMessageHandler(ApplicationTools::warning.get());
     pl.setParameter(i, ap);
   }
 
@@ -310,7 +311,7 @@ FrequenciesSet* PhylogeneticsApplicationTools::getRootFrequenciesSet(
   const std::string& suffix,
   bool suffixIsOptional,
   bool verbose,
-  int warn) throw (Exception)
+  int warn)
 {
   string freqDescription = ApplicationTools::getStringParameter("nonhomogeneous.root_freq", params, "Full(init=observed)", suffix, suffixIsOptional, warn);
   if (freqDescription == "None")
@@ -346,7 +347,7 @@ FrequenciesSet* PhylogeneticsApplicationTools::getFrequenciesSet(
   std::map<std::string, std::string>& sharedparams,
   const std::vector<double>& rateFreqs,
   bool verbose,
-  int warn) throw (Exception)
+  int warn)
 {
   map<string, string> unparsedParameterValues;
   BppOFrequenciesSetFormat bIO(BppOFrequenciesSetFormat::ALL, verbose, warn);
@@ -463,6 +464,7 @@ void PhylogeneticsApplicationTools::setSubstitutionModelSet(
 
   unique_ptr<TransitionModel> tmp(bIO.readTransitionModel(alphabet, tmpDesc, data, false));
 
+
   if (tmp->getNumberOfStates() != alphabet->getSize())
   {
     // Markov-Modulated Markov Model...
@@ -526,8 +528,8 @@ void PhylogeneticsApplicationTools::setSubstitutionModelSet(
 
     unparsedParameters.insert(sharedParameters.begin(), sharedParameters.end());
 
-    vector<int> nodesId = ApplicationTools::getVectorParameter<int>(prefix + ".nodes_id", params, ',', ':', TextTools::toString(i), suffix, suffixIsOptional, warn);
-
+    vector<int> nodesId = ApplicationTools::getVectorParameter<int>(prefix + ".nodes_id", params, ',', ':', "", suffix, suffixIsOptional, warn);
+    
     if (verbose)
       ApplicationTools::displayResult("Model" + TextTools::toString(i + 1) + " is associated to", TextTools::toString(nodesId.size()) + " node(s).");
 
@@ -696,7 +698,7 @@ DiscreteDistribution* PhylogeneticsApplicationTools::getRateDistribution(
   map<string, string>& params,
   const string& suffix,
   bool suffixIsOptional,
-  bool verbose) throw (Exception)
+  bool verbose)
 {
   string distDescription = ApplicationTools::getStringParameter("rate_distribution", params, "Constant()", suffix, suffixIsOptional);
 
@@ -731,7 +733,6 @@ TreeLikelihood* PhylogeneticsApplicationTools::optimizeParameters(
   bool suffixIsOptional,
   bool verbose,
   int warn)
-throw (Exception)
 {
   string optimization = ApplicationTools::getStringParameter("optimization", params, "FullD(derivatives=Newton)", suffix, suffixIsOptional, warn);
   if (optimization == "None")
@@ -745,7 +746,7 @@ throw (Exception)
   string mhPath = ApplicationTools::getAFilePath("optimization.message_handler", params, false, false, suffix, suffixIsOptional, "none", warn + 1);
   OutputStream* messageHandler =
     (mhPath == "none") ? 0 :
-    (mhPath == "std") ? ApplicationTools::message :
+    (mhPath == "std") ? ApplicationTools::message.get() :
     new StlOutputStream(new ofstream(mhPath.c_str(), ios::out));
   if (verbose)
     ApplicationTools::displayResult("Message handler", mhPath);
@@ -753,7 +754,7 @@ throw (Exception)
   string prPath = ApplicationTools::getAFilePath("optimization.profiler", params, false, false, suffix, suffixIsOptional, "none", warn + 1);
   OutputStream* profiler =
     (prPath == "none") ? 0 :
-    (prPath == "std") ? ApplicationTools::message :
+    (prPath == "std") ? ApplicationTools::message.get() :
     new StlOutputStream(new ofstream(prPath.c_str(), ios::out));
   if (profiler)
     profiler->setPrecision(20);
@@ -976,9 +977,14 @@ throw (Exception)
           }
           string pname  = stp.nextToken();
           string pvalue = stp.nextToken();
-          size_t p = pl.whichParameterHasName(pname);
-          pl.setParameter(p, AutoParameter(pl[p]));
-          pl[p].setValue(TextTools::toDouble(pvalue));
+          try {
+            size_t p = pl.whichParameterHasName(pname);
+            pl.setParameter(p, AutoParameter(pl[p]));
+            pl[p].setValue(TextTools::toDouble(pvalue));
+          }
+          catch(Exception& e)
+          {
+          }
         }
       }
       bck.close();
@@ -1154,7 +1160,6 @@ void PhylogeneticsApplicationTools::optimizeParameters(
   bool suffixIsOptional,
   bool verbose,
   int warn)
-throw (Exception)
 {
   string optimization = ApplicationTools::getStringParameter("optimization", params, "FullD(derivatives=Newton)", suffix, suffixIsOptional, warn);
   if (optimization == "None")
@@ -1168,7 +1173,7 @@ throw (Exception)
   string mhPath = ApplicationTools::getAFilePath("optimization.message_handler", params, false, false, suffix, suffixIsOptional, "none", warn + 1);
   OutputStream* messageHandler =
     (mhPath == "none") ? 0 :
-    (mhPath == "std") ? ApplicationTools::message :
+    (mhPath == "std") ? ApplicationTools::message.get() :
     new StlOutputStream(new ofstream(mhPath.c_str(), ios::out));
   if (verbose)
     ApplicationTools::displayResult("Message handler", mhPath);
@@ -1176,7 +1181,7 @@ throw (Exception)
   string prPath = ApplicationTools::getAFilePath("optimization.profiler", params, false, false, suffix, suffixIsOptional, "none", warn + 1);
   OutputStream* profiler =
     (prPath == "none") ? 0 :
-    (prPath == "std") ? ApplicationTools::message :
+    (prPath == "std") ? ApplicationTools::message.get() :
     new StlOutputStream(new ofstream(prPath.c_str(), ios::out));
   if (profiler)
     profiler->setPrecision(20);
@@ -1396,7 +1401,7 @@ void PhylogeneticsApplicationTools::writeTree(
   bool suffixIsOptional,
   bool verbose,
   bool checkOnly,
-  int warn) throw (Exception)
+  int warn)
 {
   string format = ApplicationTools::getStringParameter(prefix + "tree.format", params, "Newick", suffix, suffixIsOptional, warn);
   string file = ApplicationTools::getAFilePath(prefix + "tree.file", params, false, false, suffix, suffixIsOptional, "none", warn);
@@ -1422,7 +1427,7 @@ void PhylogeneticsApplicationTools::writeTrees(
   bool suffixIsOptional,
   bool verbose,
   bool checkOnly,
-  int warn) throw (Exception)
+  int warn)
 {
   string format = ApplicationTools::getStringParameter(prefix + "trees.format", params, "Newick", suffix, suffixIsOptional, warn);
   string file = ApplicationTools::getAFilePath(prefix + "trees.file", params, true, false, suffix, suffixIsOptional, "none", warn);
@@ -1469,7 +1474,7 @@ void PhylogeneticsApplicationTools::printParameters(const SubstitutionModelSet*
   // Loop over all models:
   for (size_t i = 0; i < modelSet->getNumberOfModels(); i++)
   {
-    const TransitionModel* model = modelSet->getTransitionModel(i);
+    const TransitionModel* model = modelSet->getModel(i);
 
     map<string, string> aliases;
 
@@ -1552,6 +1557,7 @@ void PhylogeneticsApplicationTools::printParameters(const DiscreteDistribution*
 /************************
 * Substitution Mapping *
 ************************/
+
 SubstitutionCount* PhylogeneticsApplicationTools::getSubstitutionCount(
   const Alphabet* alphabet,
   const SubstitutionModel* model,
@@ -1612,4 +1618,139 @@ SubstitutionCount* PhylogeneticsApplicationTools::getSubstitutionCount(
   return substitutionCount;
 }
 
-/******************************************************************************/
+/****************************************************************************/
+
+
+SubstitutionRegister* PhylogeneticsApplicationTools::getSubstitutionRegister(const std::string& regTypeDesc, const SubstitutionModel* model, bool verbose)
+{
+  string regType = "";
+  map<string, string> regArgs;
+  KeyvalTools::parseProcedure(regTypeDesc, regType, regArgs);
+  
+  SubstitutionRegister* reg = 0;
+
+  if (regType=="Combination")
+  {
+    VectorOfSubstitionRegisters* vreg= new VectorOfSubstitionRegisters(model);
+
+    size_t i = 0;
+    while (++i)
+    {
+      string regDesc = ApplicationTools::getStringParameter("reg" + TextTools::toString(i), regArgs, "", "", false, 1);
+      if (regDesc=="")
+        break;
+      
+      SubstitutionRegister* sreg=getSubstitutionRegister(regDesc, model);
+
+      vreg->addRegister(sreg);
+    }
+    
+    reg=vreg;
+  }
+  else if (regType == "All")
+  {
+    reg = new ComprehensiveSubstitutionRegister(model, false);
+  }
+  else if (regType == "Total")
+  {
+    reg = new TotalSubstitutionRegister(model);
+  }    
+  else if (regType == "Selected"){  
+    string subsList = ApplicationTools::getStringParameter("substitution.list", regArgs, "All", "", true, false);
+    reg = new SelectedSubstitutionRegister(model, subsList);  
+  }
+
+  
+  // Alphabet dependent registers
+
+  
+  else if (AlphabetTools::isNucleicAlphabet(model->getAlphabet()))
+  {
+    const NucleotideSubstitutionModel* nmodel=dynamic_cast<const NucleotideSubstitutionModel*>(model);
+    if (!nmodel)
+    {
+      const WrappedSubstitutionModel* wmodel=dynamic_cast<const WrappedSubstitutionModel*>(model);
+      if (wmodel)
+      {
+        nmodel=dynamic_cast<const NucleotideSubstitutionModel*>(&wmodel->getSubstitutionModel());
+      }
+    }
+
+    if (!nmodel)
+      throw Exception("PhylogeneticsApplicationTools::getSubstitutionRegister : model and alphabet do not fit " + model->getAlphabet()->getAlphabetType() + " vs " + model->getName());
+
+    
+    if (regType == "GC")
+      reg = new GCSubstitutionRegister(nmodel, false);
+    else if (regType == "TsTv")
+      reg = new TsTvSubstitutionRegister(nmodel);
+    else if (regType == "SW")
+      reg = new SWSubstitutionRegister(nmodel);
+    else
+      throw Exception("Unsupported substitution categorization: " + regType + " for alphabet " + model->getAlphabet()->getAlphabetType());
+  }
+  
+  else if (AlphabetTools::isCodonAlphabet(model->getAlphabet()))
+  {
+    const CodonSubstitutionModel* cmodel=dynamic_cast<const CodonSubstitutionModel*>(model);
+    if (!cmodel)
+    {
+      const WrappedSubstitutionModel* wmodel=dynamic_cast<const WrappedSubstitutionModel*>(model);
+      if (wmodel)
+      {
+        cmodel=dynamic_cast<const CodonSubstitutionModel*>(&wmodel->getSubstitutionModel());
+      }
+    }
+
+    if (!cmodel)
+      throw Exception("PhylogeneticsApplicationTools::getSubstitutionRegister : model and alphabet do not fit " + model->getAlphabet()->getAlphabetType() + " vs " + model->getName());
+  
+    if (regType == "IntraAA")
+      reg = new AAInteriorSubstitutionRegister(cmodel);
+    else if (regType == "InterAA")
+      reg = new AAExteriorSubstitutionRegister(cmodel);
+    else if (regType == "GC")
+      reg = new GCSynonymousSubstitutionRegister(cmodel);
+    else if (regType == "TsTv")
+      reg = new TsTvSubstitutionRegister(cmodel);
+    else if (regType == "SW")
+      reg = new SWSubstitutionRegister(cmodel);
+    else if (regType == "KrKc")
+      reg = new KrKcSubstitutionRegister(cmodel);
+    else if (regType == "DnDs")
+      reg = new DnDsSubstitutionRegister(cmodel, false);
+    else
+      throw Exception("Unsupported substitution categorization: " + regType + " for alphabet " + model->getAlphabet()->getAlphabetType());
+  }
+  
+  else if (AlphabetTools::isProteicAlphabet(model->getAlphabet()))
+  {
+    const ProteinSubstitutionModel* pmodel=dynamic_cast<const ProteinSubstitutionModel*>(model);
+    if (!pmodel)
+    {
+      const WrappedSubstitutionModel* wmodel=dynamic_cast<const WrappedSubstitutionModel*>(model);
+      if (wmodel)
+      {
+        pmodel=dynamic_cast<const ProteinSubstitutionModel*>(&wmodel->getSubstitutionModel());
+      }
+    }
+
+    if (!pmodel)
+      throw Exception("PhylogeneticsApplicationTools::getSubstitutionRegister : model and alphabet do not fit " + model->getAlphabet()->getAlphabetType() + " vs " + model->getName());
+  
+    if (regType == "KrKc")
+      reg = new KrKcSubstitutionRegister(pmodel);
+    else
+      throw Exception("Unsupported substitution categorization: " + regType + " for alphabet " + model->getAlphabet()->getAlphabetType());
+  }
+  
+  CategorySubstitutionRegister* csr=dynamic_cast<CategorySubstitutionRegister*>(reg);
+  if (csr)
+    csr->setStationarity(ApplicationTools::getBooleanParameter("stationarity", regArgs, true));
+
+  if (verbose)
+    ApplicationTools::displayResult("Substitution Register", regType);
+
+  return reg;
+}
+
