@@ -177,6 +177,9 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
 
     const WordAlphabet* pWA = dynamic_cast<const WordAlphabet*>(alphabet);
 
+    if (pWA==NULL)
+      throw Exception("BppOFrequenciesSetFormat::read : Word freq name is from WordAlphabet.");
+    
     if (args.find("frequency") != args.end())
     {
       string sAFS = args["frequency"];
@@ -266,7 +269,7 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
       string sAFS = args["frequency"];
 
       BppOFrequenciesSetFormat nestedReader(alphabetCode_, false, warningLevel_);
-      unique_ptr<FrequenciesSet> pFS2(nestedReader.read(pWA->getNAlphabet(0), sAFS, data, false));
+      unique_ptr<FrequenciesSet> pFS2(nestedReader.read(pWA->getNucleicAlphabet(), sAFS, data, false));
       map<string, string> unparsedParameterValuesNested(nestedReader.getUnparsedArguments());
 
       for (map<string, string>::iterator it = unparsedParameterValuesNested.begin(); it != unparsedParameterValuesNested.end(); it++)
@@ -295,7 +298,7 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
       for (size_t i = 0; i < v_sAFS.size(); ++i)
       {
         BppOFrequenciesSetFormat nestedReader(alphabetCode_, false, warningLevel_);
-        pFS.reset(nestedReader.read(pWA->getNAlphabet(i), v_sAFS[i], data, false));
+        pFS.reset(nestedReader.read(pWA->getNucleicAlphabet(), v_sAFS[i], data, false));
         map<string, string> unparsedParameterValuesNested(nestedReader.getUnparsedArguments());
         for (map<string, string>::iterator it = unparsedParameterValuesNested.begin(); it != unparsedParameterValuesNested.end(); it++)
         {
@@ -388,7 +391,7 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
         string sAFS = args["frequency"];
         
         BppOFrequenciesSetFormat nestedReader(alphabetCode_, false, warningLevel_);
-        unique_ptr<FrequenciesSet> pFS2(nestedReader.read(pWA->getNAlphabet(0), sAFS, data, false));
+        unique_ptr<FrequenciesSet> pFS2(nestedReader.read(pWA->getNucleicAlphabet(), sAFS, data, false));
         if (pFS2->getName()!="Full")
           throw Exception("BppOFrequenciesSetFormat::read. The frequency option in F1X4 can only be Full");
         
@@ -440,7 +443,7 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
           {
             BppOFrequenciesSetFormat nestedReader(alphabetCode_, false, warningLevel_);
             if (v_sAFS[i]!=""){
-              pFS.reset(nestedReader.read(pWA->getNAlphabet(i), v_sAFS[i], data, false));
+              pFS.reset(nestedReader.read(pWA->getNucleicAlphabet(), v_sAFS[i], data, false));
               if (pFS->getName()!="Full")
                 throw Exception("BppOFrequenciesSetFormat::read. The frequency options in F3X4 can only be Full");
 
@@ -520,7 +523,6 @@ FrequenciesSet* BppOFrequenciesSetFormat::read(const Alphabet* alphabet, const s
     {
       pname2 = pFS->getParameterNameWithoutNamespace(pl[j].getName());
 
-      // if (j == i || args.find(pname2) == args.end()) continue; Julien 03/03/2010: This extra condition prevents complicated (nested) models to work properly...
       if (j == i)
         continue;
       if (pval == pname2)
@@ -780,7 +782,7 @@ void BppOFrequenciesSetFormat::initialize_(FrequenciesSet& freqSet, const SiteCo
     {
       AutoParameter ap(pl[i]);
       if (verbose_)
-        ap.setMessageHandler(ApplicationTools::warning);
+        ap.setMessageHandler(ApplicationTools::warning.get());
       pl.setParameter(i, ap);
     }
 
