@@ -5,7 +5,7 @@
 //
 
 /*
-Copyright or © or Copr. CNRS, (November 16, 2004)
+Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)
 
 This software is a computer program whose purpose is to provide classes
 for phylogenetic data analysis.
@@ -170,7 +170,7 @@ class AbstractOTree:
         write(tree, output);
         output.close();
       }
-      catch (IOException e)
+      catch (IOException& e)
         {
           std::stringstream ss ;
           ss << e.what() <<"\nProblem writing tree to file "<< path <<"\n Is the file path correct and do \
