@@ -80,7 +80,7 @@ public:
    * @return A pointer toward a new ITree object.
    * @throw Exception If the format name do not match any available format.
    */
-  virtual ITree* createReader(const std::string& format) throw (Exception);
+  virtual ITree* createReader(const std::string& format);
   
   /**
    * @brief Get a new dynamically created OTree object.
@@ -89,7 +89,7 @@ public:
    * @return A pointer toward a new OTree object.
    * @throw Exception If the format name do not match any available format.
    */
-  virtual OTree* createWriter(const std::string& format) throw (Exception);
+  virtual OTree* createWriter(const std::string& format);
 };
 
 } //end of namespace bpp.
