@@ -111,8 +111,7 @@ namespace bpp
                                DiscreteDistribution* rDist,
                                bool checkRooted = true,
                                bool verbose = true,
-                               bool usePatterns = true)
-      throw (Exception);
+                               bool usePatterns = true);
 	
     /**
      * @brief Build a new RHomogeneousTreeLikelihood object with data.
@@ -136,8 +135,7 @@ namespace bpp
                                DiscreteDistribution* rDist,
                                bool checkRooted = true,
                                bool verbose = true,
-                               bool usePatterns = true)
-      throw (Exception);
+                               bool usePatterns = true);
 
     RHomogeneousTreeLikelihood(const RHomogeneousTreeLikelihood& lik);
     
@@ -152,7 +150,7 @@ namespace bpp
     /**
      * @brief Method called by constructors.
      */
-    void init_(bool usePatterns) throw (Exception);
+    void init_(bool usePatterns);
 	
   public:
 
@@ -163,7 +161,7 @@ namespace bpp
      *
      * @{
      */
-    void setData(const SiteContainer& sites) throw (Exception);
+    void setData(const SiteContainer& sites);
     double getLikelihood() const;
     double getLogLikelihood() const;
     double getLikelihoodForASite (size_t site) const;
@@ -195,17 +193,17 @@ namespace bpp
      *
      * @param parameters The parameter list to pass to the function.
      */
-    void setParameters(const ParameterList& parameters) throw (ParameterNotFoundException, ConstraintException);
-    double getValue() const throw(Exception);
+    void setParameters(const ParameterList& parameters);
+    double getValue() const;
 		
-    size_t getSiteIndex(size_t site) const throw (IndexOutOfBoundsException) { return likelihoodData_->getRootArrayPosition(site); }
+    size_t getSiteIndex(size_t site) const { return likelihoodData_->getRootArrayPosition(site); }
 
     /**
      * @name DerivableFirstOrder interface.
      *
      * @{
      */
-    double getFirstOrderDerivative(const std::string& variable) const throw (Exception);
+    double getFirstOrderDerivative(const std::string& variable) const;
     /** @} */
 
     /**
@@ -213,8 +211,8 @@ namespace bpp
      *
      * @{
      */
-    double getSecondOrderDerivative(const std::string& variable) const throw (Exception);
-    double getSecondOrderDerivative(const std::string& variable1, const std::string& variable2) const throw (Exception) { return 0; } // Not implemented for now.
+    double getSecondOrderDerivative(const std::string& variable) const;
+    double getSecondOrderDerivative(const std::string& variable1, const std::string& variable2) const { return 0; } // Not implemented for now.
     /** @} */
 	
   public:	// Specific methods:
