@@ -168,7 +168,7 @@ namespace bpp
       supportedChars_ = model->getAlphabetStates();
     }
 
-    void setSubstitutionRegister(SubstitutionRegister* reg) throw (Exception) {
+    void setSubstitutionRegister(SubstitutionRegister* reg) {
       throw Exception("OneJumpSubstitutionCount::setSubstitutionRegister. This SubstitutionsCount only works with a TotalSubstitutionRegister.");
     }
 
