@@ -59,7 +59,7 @@ ProbabilisticRewardMapping* RewardMappingTools::computeRewardVectors(
   const DRTreeLikelihood& drtl,
   const vector<int>& nodeIds,
   Reward& reward,
-  bool verbose) throw (Exception)
+  bool verbose)
 {
   // Preamble:
   if (!drtl.isInitialized())
@@ -332,9 +332,8 @@ ProbabilisticRewardMapping* RewardMappingTools::computeRewardVectors(
 
     // Now we just have to copy the substitutions into the result vector:
     for (size_t i = 0; i < nbSites; ++i)
-    {
       (*rewards)(l, i) = rewardsForCurrentNode[(*rootPatternLinks)[i]] / Lr[(*rootPatternLinks)[i]];
-    }
+
   }
   if (verbose)
   {
@@ -351,7 +350,6 @@ void RewardMappingTools::writeToStream(
   const ProbabilisticRewardMapping& rewards,
   const SiteContainer& sites,
   ostream& out)
-throw (IOException)
 {
   if (!out)
     throw IOException("RewardMappingTools::writeToFile. Can't write to stream.");
@@ -377,7 +375,6 @@ throw (IOException)
 /**************************************************************************************************/
 
 void RewardMappingTools::readFromStream(istream& in, ProbabilisticRewardMapping& rewards)
-throw (IOException)
 {
   try
   {
