@@ -48,7 +48,6 @@ using namespace std;
 AbstractCodonPhaseFrequenciesSubstitutionModel::AbstractCodonPhaseFrequenciesSubstitutionModel(
   FrequenciesSet* pfreq,
   const std::string& prefix) :
-  CodonSubstitutionModel(),
   AbstractParameterAliasable(prefix),
   posfreqset_(),
   freqName_("")
@@ -66,12 +65,12 @@ AbstractCodonPhaseFrequenciesSubstitutionModel::AbstractCodonPhaseFrequenciesSub
     if (dynamic_cast<FixedCodonFrequenciesSet*>(pCFS)) {
       for (unsigned int i = 0; i < 3; i++)
       {
-        vFS.push_back(new FixedNucleotideFrequenciesSet(pCFS->getAlphabet()->getNucleicAlphabet()));
+        vFS.push_back(new FixedNucleotideFrequenciesSet(pCFS->getCodonAlphabet()->getNucleicAlphabet()));
       }
     } else {
       for (unsigned int i = 0; i < 3; i++)
       {
-        vFS.push_back(new FullNucleotideFrequenciesSet(pCFS->getAlphabet()->getNucleicAlphabet()));
+        vFS.push_back(new FullNucleotideFrequenciesSet(pCFS->getCodonAlphabet()->getNucleicAlphabet()));
       }
     }
     posfreqset_ = new CodonFromIndependentFrequenciesSet(
@@ -83,8 +82,8 @@ AbstractCodonPhaseFrequenciesSubstitutionModel::AbstractCodonPhaseFrequenciesSub
 
   freqName_ = pfreq->getNamespace();
   posfreqset_->setNamespace(prefix + pfreq->getNamespace());
-  //  if (dynamic_cast<FixedCodonFrequenciesSet*>(pCFS)!=NULL)
   addParameters_(posfreqset_->getParameters());
+  fireParameterChanged(posfreqset_->getParameters());
 }
 
 AbstractCodonPhaseFrequenciesSubstitutionModel::~AbstractCodonPhaseFrequenciesSubstitutionModel()
