@@ -53,7 +53,7 @@ MixtureOfASubstitutionModel::MixtureOfASubstitutionModel(
   SubstitutionModel* model,
   std::map<std::string, DiscreteDistribution*> parametersDistributionsList,
   int ffrom,
-  int tto) throw (Exception) :
+  int tto) :
   AbstractParameterAliasable(model->getNamespace()),
   AbstractMixedSubstitutionModel(alpha, model->getStateMap().clone(), model->getNamespace()),
   distributionMap_(),
@@ -287,7 +287,7 @@ const SubstitutionModel* MixtureOfASubstitutionModel::getSubModelWithName(const
   return NULL;
 }
 
-Vint MixtureOfASubstitutionModel::getSubmodelNumbers(string& desc) const
+Vint MixtureOfASubstitutionModel::getSubmodelNumbers(const string& desc) const
 {
   vector<string> parnames = modelsContainer_[0]->getParameters().getParameterNames();
   std::map<std::string, size_t> msubn;
