@@ -112,7 +112,7 @@ public:
       const Alphabet* alpha,
       SubstitutionModel* model,
       std::map<std::string, DiscreteDistribution*> parametersDistributionsList,
-      int ffrom = -1, int tto = -1) throw (Exception);
+      int ffrom = -1, int tto = -1);
 
   MixtureOfASubstitutionModel(const MixtureOfASubstitutionModel&);
 
@@ -145,7 +145,7 @@ public:
    *
    */
 
-  Vint getSubmodelNumbers(std::string& desc) const;
+  Vint getSubmodelNumbers(const std::string& desc) const;
 
   /**
    * @brief sets the eq frequencies of the first nested model, and
