@@ -41,11 +41,10 @@ knowledge of the CeCILL license and that you accept its terms.
 #define _F84_H_
 
 #include "NucleotideSubstitutionModel.h"
-#include "../AbstractSubstitutionModel.h"
 
 #include <Bpp/Numeric/Constraints.h>
 
-// From SeqLib:
+// From bpp-seq:
 #include <Bpp/Seq/Alphabet/NucleicAlphabet.h>
 
 namespace bpp
@@ -97,7 +96,7 @@ namespace bpp
  * 1 & \left(1 + \kappa/\pi_Y\right) & 1 & \frac{-\pi_G-\left(1 + \kappa/\pi_Y\right)\pi_C-\pi_A}{\pi_T} \\ 
  * \end{pmatrix}
  * \f]
- * with \f$P=2k\left({frac{piC.piT}{piT+piC}}+{\frac{piA.piG}{piG+piA}}\right)-piT^2-piG^2-piC^2-piA^2+1\f$.
+ * with \f$P=2\kappa \left({\frac{\pi_C \pi_T}{\pi_T+\pi_C}}+{\frac{\pi_A \pi_G}{\pi_G+\pi_A}}\right)-\pi_T^2-\pi_G^2-\pi_C^2-\pi_A^2+1\f$.
  *
  * The normalized generator is obtained by taking the dot product of \f$S\f$ and \f$\pi\f$:
  * \f[
@@ -176,8 +175,7 @@ namespace bpp
  * - Felsenstein (1984), Phylip version 2.6. 
  */
 class F84:
-  public virtual NucleotideSubstitutionModel,
-  public AbstractReversibleSubstitutionModel
+  public AbstractReversibleNucleotideSubstitutionModel
 {
   private:
     double kappa_, piA_, piC_, piG_, piT_, piY_, piR_, r_, k1_, k2_, theta_, theta1_, theta2_;
@@ -195,12 +193,7 @@ class F84:
   
     virtual ~F84() {}
 
-#ifndef NO_VIRTUAL_COV
-    F84*
-#else
-    Clonable*
-#endif
-    clone() const { return new F84(*this); }
+    F84* clone() const { return new F84(*this); }
 
   public:
 
