@@ -52,7 +52,7 @@ using namespace std;
 
 K80::K80(const NucleicAlphabet* alpha, double kappa) :
 AbstractParameterAliasable("K80."),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "K80."),
+  AbstractReversibleNucleotideSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "K80."),
   kappa_(kappa), r_(), l_(), k_(), exp1_(), exp2_(), p_(size_, size_)
 {
   addParameter_(new Parameter("K80.kappa", kappa, &Parameter::R_PLUS_STAR));
@@ -65,7 +65,7 @@ void K80::updateMatrices()
 {
   kappa_ = getParameterValue("kappa");
   k_ = (kappa_ + 1.) / 2.;
-  r_ = 4. / (kappa_ + 2.);
+  r_ = isScalable()?4. / (kappa_ + 2.):4;
 	
   // Frequences:
   freq_[0] = freq_[1] = freq_[2] = freq_[3] = 1. / 4.;
@@ -91,7 +91,7 @@ void K80::updateMatrices()
   generator_(3, 1) = kappa_;
 
   // Normalization:
-  MatrixTools::scale(generator_, r_/4);
+  setScale(r_/4);
 
   // Exchangeability:
   exchangeability_ = generator_;
