@@ -52,7 +52,7 @@ using namespace std;
 
 DSO78::DSO78(const ProteicAlphabet* alpha) :
   AbstractParameterAliasable("DSO78."),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "DSO78."),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "DSO78."),
   freqSet_(0)
 {
   #include "__DSO78ExchangeabilityCode"
@@ -63,7 +63,7 @@ DSO78::DSO78(const ProteicAlphabet* alpha) :
 
 DSO78::DSO78(const ProteicAlphabet* alpha, ProteinFrequenciesSet* freqSet, bool initFreqs) :
   AbstractParameterAliasable("DSO78+F."),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "DSO78+F."),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "DSO78+F."),
   freqSet_(freqSet)
 {
   #include "__DSO78ExchangeabilityCode"
@@ -86,7 +86,10 @@ void DSO78::setFreqFromData(const SequenceContainer& data, double pseudoCount)
   {
     t += (counts[i] + pseudoCount);
   }
-  for (size_t i = 0; i < size_; ++i) freq_[i] = (static_cast<double>(counts[static_cast<int>(i)]) + pseudoCount) / t;
+  for (size_t i = 0; i < size_; ++i) {
+    freq_[i] = (static_cast<double>(counts[static_cast<int>(i)]) + pseudoCount) / t;
+    //ApplicationTools::displayResult("-- Frequency for " + alphabet_->intToChar(static_cast<int>(i)), freq_[i]);
+  }
   freqSet_->setFrequencies(freq_);
   //Update parameters and re-compute generator and eigen values:
   matchParametersValues(freqSet_->getParameters());
