@@ -52,7 +52,7 @@ using namespace std;
 
 JTT92::JTT92(const ProteicAlphabet* alpha) :
   AbstractParameterAliasable("JTT92."),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "JTT92."),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "JTT92."),
   freqSet_(0)
 {
   #include "__JTT92ExchangeabilityCode"
@@ -63,7 +63,7 @@ JTT92::JTT92(const ProteicAlphabet* alpha) :
 
 JTT92::JTT92(const ProteicAlphabet* alpha, ProteinFrequenciesSet* freqSet, bool initFreqs) :
   AbstractParameterAliasable("JTT92+F."),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "JTT92+F."),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "JTT92+F."),
   freqSet_(freqSet)
 {
   #include "__JTT92ExchangeabilityCode"
