@@ -44,6 +44,7 @@ knowledge of the CeCILL license and that you accept its terms.
 #include <Bpp/Text/TextTools.h>
 #include <Bpp/Text/StringTokenizer.h>
 #include <Bpp/Numeric/VectorTools.h>
+#include <Bpp/Io/FileTools.h>
 
 //From SeqLib:
 #include <Bpp/Seq/Container/SequenceContainerTools.h>
@@ -62,7 +63,7 @@ using namespace std;
 UserProteinSubstitutionModel::UserProteinSubstitutionModel(
     const ProteicAlphabet* alpha, const std::string& path, const std::string& prefix) : 
   AbstractParameterAliasable(prefix),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), prefix),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), prefix),
   path_(path),
   freqSet_(0)
 {
@@ -76,7 +77,7 @@ UserProteinSubstitutionModel::UserProteinSubstitutionModel(
     ProteinFrequenciesSet* freqSet, const std::string& prefix,
     bool initFreqs) : 
   AbstractParameterAliasable(prefix),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), prefix),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), prefix),
   path_(path),
   freqSet_(freqSet)
 {
@@ -102,6 +103,9 @@ std::string UserProteinSubstitutionModel::getName() const
 
 void UserProteinSubstitutionModel::readFromFile()
 {
+  if (!FileTools::fileExists(path_.c_str()))
+    throw Exception("UserProteinSubstitutionModel::readFromFile. Frequencies file not found : " +  path_);
+  
   ifstream in(path_.c_str(), ios::in);
   //Read exchangeability matrix:
   for (unsigned int i = 1; i < 20; i++)
